# The main GetterCyndi5 driver
class GetterCyndi5
  # Getter
  #
  # Example:
  #   >> GetterCyndi5.go(
  #         base_url = 'https://thehappyco.com',
  #         products_page_path = '/kelly/products',
  #         item_row_selector = '.item-row',
  #         item_anchor_selector = 'div > div.product-desc.text-center > div.product-title > h3 > a',
  #         item_price_selector = 'div > div.product-desc.text-center > div.product-price',
  #         price_a_text: 'One Time Purchase',
  #         price_b_text: 'SmartShip',
  #         mode = 2,
  #         filename = './tmp/test_document.html'
  #     )
  # Arguments:
  #   base_url: (String)
  #   products_page_path: (String) 
  #   item_row_selector: (String) 
  #   item_anchor_selector: (String)
  #   item_price_selector: (String)
  #   price_a_text: (String)
  #   price_b_text: (String)
  #   mode: (Integer)
  #     0 = retrieve and parse without saving HTML document to file,
  #     1 = retrieve and parse saving HTML document to file,
  #     2 = load and parse HTML document from file
  #   filename: (String)

  def self.go(options = {})
    all_products = products(**options)
    all_products.each do |product|
      puts "#{product.inspect}"
    end
  end

  def self.products(options = {})
    retriever = Retriever.new(**options)
    retriever.retrieve

    parser = Parser.new(document: retriever.document, **options)
    products = parser.parse
  end
end

require 'getter_cyndi5/retriever'
require 'getter_cyndi5/parser'
require 'getter_cyndi5/importer'